==> activity-center-api-1.2.10.3-20161130.022354-1-sources.jar: cn/com/duiba/activity/center/api/dto/seckill/DuibaSeckillDto.java <==
package cn.com.duiba.activity.center.api.dto.seckill;

import java.io.Serializable;
import java.util.Date;

/**
 * 和 DuibaSeckillEntity 字段对应
 */
public class DuibaSeckillDto implements Serializable {

    private static final long serialVersionUID = 123123215L;

    public static final Integer SWITCHES_DIRECT = 0; // 定向发放
    public static final Integer SWITCHES_DEV_BLACKLIST = 1; // 黑名单商品
    public static final Integer SWITCHES_ACTIVITY = 2; // 活动专用

    public static final int STATUS_OPEN = 1; // 开启且可见
    public static final int STATUS_CLOSE_SHOW = 2; // 关闭且可见
    public static final int STATUS_CLOSE = 3; // 关闭不可见

    private Long id;

    private Long itemId;

    private String title;

    private Integer status;

    private Date dateStart;

    private Date dateEnd;

    private Date timeStart;

    private Date timeEnd;

    private String rule;

    private String banner;

    private String smallImage;

    private String whiteImage;

    private String logo;

    private String multiImage;

    private String recommendImage;

    private Integer switches;

    private Date autoOffDate;

    private Boolean deleted;

    private Date gmtCreate;

    private Date gmtModified;

    private String tag;

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }


    public void openSwitch(int s) {
        int v = 1 << s;
        switches = switches | v;
    }

    public void closeSwitch(int s) {
        int v = 1 << s;
        v = ~v;
        switches = switches & v;
    }

    public boolean isOpenSwitch(int s) {
        int v = 1 << s;
        int ret = switches & v;
        return ret != 0;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Date getDateStart() {
        return dateStart;
    }

    public void setDateStart(Date dateStart) {
        this.dateStart = dateStart;
    }

    public Date getDateEnd() {
        return dateEnd;
    }

    public void setDateEnd(Date dateEnd) {
        this.dateEnd = dateEnd;
    }

    public Date getTimeStart() {
        return timeStart;
    }

    public void setTimeStart(Date timeStart) {
        this.timeStart = timeStart;
    }

    public Date getTimeEnd() {
        return timeEnd;
    }

    public void setTimeEnd(Date timeEnd) {
        this.timeEnd = timeEnd;
    }

    public String getRule() {
        return rule;
    }

    public void setRule(String rule) {
        this.rule = rule;
    }

    public String getBanner() {
        return banner;
    }

    public void setBanner(String banner) {
        this.banner = banner;
    }

    public String getSmallImage() {
        return smallImage;
    }

    public void setSmallImage(String smallImage) {
        this.smallImage = smallImage;
    }

    public String getWhiteImage() {
        return whiteImage;
    }

    public void setWhiteImage(String whiteImage) {
        this.whiteImage = whiteImage;
    }

    public String getLogo() {
        return logo;
    }

    public void setLogo(String logo) {
        this.logo = logo;
    }

    public String getMultiImage() {
        return multiImage;
    }

    public void setMultiImage(String multiImage) {
        this.multiImage = multiImage;
    }

    public String getRecommendImage() {
        return recommendImage;
    }

    public void setRecommendImage(String recommendImage) {
        this.recommendImage = recommendImage;
    }

    public Integer getSwitches() {
        return switches;
    }

    public void setSwitches(Integer switches) {
        this.switches = switches;
    }

    public Date getAutoOffDate() {
        return autoOffDate;
    }

    public void setAutoOffDate(Date autoOffDate) {
        this.autoOffDate = autoOffDate;
    }

    public Boolean getDeleted() {
        return deleted;
    }

    public void setDeleted(Boolean deleted) {
        this.deleted = deleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> activity-center-api-1.4.4-20170323.055741-1-sources.jar: cn/com/duiba/activity/center/api/dto/seckill/DuibaSeckillDto.java <==
package cn.com.duiba.activity.center.api.dto.seckill;

import java.io.Serializable;
import java.util.Date;

/**
 * 和 DuibaSeckillEntity 字段对应
 */
public class DuibaSeckillDto implements Serializable {

    private static final long serialVersionUID = 123123215L;

    public static final Integer SWITCHES_DIRECT = 0; // 定向发放
    public static final Integer SWITCHES_DEV_BLACKLIST = 1; // 黑名单商品
    public static final Integer SWITCHES_ACTIVITY = 2; // 活动专用

    public static final int STATUS_OPEN = 1; // 开启且可见
    public static final int STATUS_CLOSE_SHOW = 2; // 关闭且可见
    public static final int STATUS_CLOSE = 3; // 关闭不可见

    private Long id;

    private Long itemId;

    private String title;

    private Integer status;

    private Date dateStart;

    private Date dateEnd;

    private Date timeStart;

    private Date timeEnd;

    private String rule;

    private String banner;

    private String smallImage;

    private String whiteImage;

    private String logo;

    private String multiImage;

    private String recommendImage;

    private Integer switches;

    private Date autoOffDate;

    private Boolean deleted;

    private Date gmtCreate;

    private Date gmtModified;

    private String tag;

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    /**
     * 
     * openSwitch:(这里用一句话描述这个方法的作用). <br/>
     * 
     * @param s
     * @since JDK 1.6
     */
    public void openSwitch(int s) {
        int v = 1 << s;
        switches = switches | v;
    }

    /**
     * 
     * closeSwitch:(这里用一句话描述这个方法的作用). <br/>
     * 
     * @param s
     * @since JDK 1.6
     */
    public void closeSwitch(int s) {
        int v = 1 << s;
        v = ~v;
        switches = switches & v;
    }

    /**
     * 
     * isOpenSwitch:(这里用一句话描述这个方法的作用). <br/>
     * 
     * @param s
     * @return
     * @since JDK 1.6
     */
    public boolean isOpenSwitch(int s) {
        int v = 1 << s;
        int ret = switches & v;
        return ret != 0;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Date getDateStart() {
        return dateStart;
    }

    public void setDateStart(Date dateStart) {
        this.dateStart = dateStart;
    }

    public Date getDateEnd() {
        return dateEnd;
    }

    public void setDateEnd(Date dateEnd) {
        this.dateEnd = dateEnd;
    }

    public Date getTimeStart() {
        return timeStart;
    }

    public void setTimeStart(Date timeStart) {
        this.timeStart = timeStart;
    }

    public Date getTimeEnd() {
        return timeEnd;
    }

    public void setTimeEnd(Date timeEnd) {
        this.timeEnd = timeEnd;
    }

    public String getRule() {
        return rule;
    }

    public void setRule(String rule) {
        this.rule = rule;
    }

    public String getBanner() {
        return banner;
    }

    public void setBanner(String banner) {
        this.banner = banner;
    }

    public String getSmallImage() {
        return smallImage;
    }

    public void setSmallImage(String smallImage) {
        this.smallImage = smallImage;
    }

    public String getWhiteImage() {
        return whiteImage;
    }

    public void setWhiteImage(String whiteImage) {
        this.whiteImage = whiteImage;
    }

    public String getLogo() {
        return logo;
    }

    public void setLogo(String logo) {
        this.logo = logo;
    }

    public String getMultiImage() {
        return multiImage;
    }

    public void setMultiImage(String multiImage) {
        this.multiImage = multiImage;
    }

    public String getRecommendImage() {
        return recommendImage;
    }

    public void setRecommendImage(String recommendImage) {
        this.recommendImage = recommendImage;
    }

    public Integer getSwitches() {
        return switches;
    }

    public void setSwitches(Integer switches) {
        this.switches = switches;
    }

    public Date getAutoOffDate() {
        return autoOffDate;
    }

    public void setAutoOffDate(Date autoOffDate) {
        this.autoOffDate = autoOffDate;
    }

    public Boolean getDeleted() {
        return deleted;
    }

    public void setDeleted(Boolean deleted) {
        this.deleted = deleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
